@@ -1,3 +1,23 @@
+/*
+ * LibGCab
+ * Copyright (c) 2012, Marc-André Lureau <marcandre.lureau@gmail.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
+ */
+
 #include "config.h"
 
 #include <stdlib.h>
@@ -92,19 +112,18 @@ main (int argc, char *argv[])
 {
     GError *error = NULL;
     GOptionContext *context;
-    int i;
 
     gchar **args = NULL;
     gchar *change = NULL;
-    int version = 0;
-    int nopath = 0;
-    int space = 0;
-    int compress = 0;
-    int list = 0;
-    int list_details = 0;
-    int create = 0;
-    int extract = 0;
-    int dump_reserved = 0;
+    gboolean version = FALSE;
+    gboolean nopath = FALSE;
+    gboolean space = FALSE;
+    gboolean compress = FALSE;
+    gboolean list = FALSE;
+    gboolean list_details = FALSE;
+    gboolean create = FALSE;
+    gboolean extract = FALSE;
+    gboolean dump_reserved = FALSE;
     GOptionEntry entries[] = {
         { "version", 0, 0, G_OPTION_ARG_NONE, &version, N_("Print program version"), NULL },
         { "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose, N_("Be verbose"), NULL },
@@ -174,7 +193,7 @@ individual files from the archive.\
 
         if (list || list_details) {
             GPtrArray *folders = gcab_cabinet_get_folders (cabinet);
-            for (i = 0; i < folders->len; i++) {
+            for (guint i = 0; i < folders->len; i++) {
                 GSList *l, *files = gcab_folder_get_files (g_ptr_array_index (folders, i));
 
                 for (l = files; l != NULL; l = l->next) {
@@ -239,7 +258,7 @@ individual files from the archive.\
 
     folder = gcab_folder_new (compress ? GCAB_COMPRESSION_MSZIP : 0);
 
-    for (i = 1; args[i]; i++) {
+    for (gint i = 1; args[i]; i++) {
         GFile *file = g_file_new_for_commandline_arg (args[i]);
         gchar *name = nopath ? g_path_get_basename (args[i]) : g_strdup (args[i]);
         GCabFile *cabfile = gcab_file_new_with_file (
