@@ -1,3 +1,26 @@
+/*
+ * LibGCab
+ * Copyright (c) 2012, Marc-André Lureau <marcandre.lureau@gmail.com>
+ * Copyright (c) 2017, Richard Hughes <richard@hughsie.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
+ */
+
+#include "config.h"
+
 #include "gcab-priv.h"
 #include <glib/gi18n-lib.h>
 
@@ -9,8 +32,7 @@ zalloc (voidpf opaque, uInt items, uInt size)
 static void
 zfree (voidpf opaque, voidpf address)
 {
-    if (address)
-        g_free (address);
+    g_free (address);
 }
 
 static gboolean
@@ -190,9 +212,10 @@ cheader_write (cheader_t *ch, GDataOutputStream *out,
         return FALSE;
 
     if (ch->flags & CABINET_HEADER_RESERVE) {
-        W2 (ch->res_header);
-        W1 (ch->res_folder);
-        W1 (ch->res_data);
+        if (!W2 (ch->res_header) ||
+            !W1 (ch->res_folder) ||
+            !W1 (ch->res_data))
+                return FALSE;
         if (g_output_stream_write (stream, ch->reserved, ch->res_header,
                                    cancellable, error) == -1)
             return FALSE;
@@ -301,7 +324,7 @@ cfolder_write (cfolder_t *cf, GDataOutputStream *out,
 }
 
 G_GNUC_INTERNAL gboolean
-cfolder_read (cfolder_t *cf, u1 res_size, GDataInputStream *in,
+cfolder_read (cfolder_t *cf, guint8 res_size, GDataInputStream *in,
               GCancellable *cancellable, GError **error)
 {
     gboolean success = FALSE;
@@ -375,32 +398,33 @@ end:
     return success;
 }
 
-typedef unsigned long int CHECKSUM;
-
-static CHECKSUM
-compute_checksum (guint8 *in, u2 ncbytes, CHECKSUM seed)
+static guint32
+compute_checksum (guint8 *in, guint16 ncbytes, guint32 seed)
 {
     int no_ulongs;
-    CHECKSUM csum=0;
-    CHECKSUM temp;
+    guint32 csum=0;
+    guint32 temp;
 
     no_ulongs = ncbytes / 4;
     csum = seed;
 
     while (no_ulongs-- > 0) {
-        temp = ((CHECKSUM) (*in++));
-        temp |= (((CHECKSUM) (*in++)) << 8);
-        temp |= (((CHECKSUM) (*in++)) << 16);
-        temp |= (((CHECKSUM) (*in++)) << 24);
+        temp = ((guint32) (*in++));
+        temp |= (((guint32) (*in++)) << 8);
+        temp |= (((guint32) (*in++)) << 16);
+        temp |= (((guint32) (*in++)) << 24);
 
         csum ^= temp;
     }
 
     temp = 0;
     switch (ncbytes % 4) {
-    case 3: temp |= (((CHECKSUM) (*in++)) << 16);
-    case 2: temp |= (((CHECKSUM) (*in++)) << 8);
-    case 1: temp |= ((CHECKSUM) (*in++));
+    case 3: temp |= (((guint32) (*in++)) << 16);
+    /* fall-thru */
+    case 2: temp |= (((guint32) (*in++)) << 8);
+    /* fall-thru */
+    case 1: temp |= ((guint32) (*in++));
+    /* fall-thru */
     default: break;
     }
 
@@ -417,8 +441,15 @@ cdata_write (cdata_t *cd, GDataOutputStream *out, int type,
     if (!cdata_set(cd, type, data, size))
         return FALSE;
 
-    CHECKSUM datacsum = compute_checksum(cd->in, cd->ncbytes, 0);
-    cd->checksum = compute_checksum ((guint8*)&cd->ncbytes, 4, datacsum);
+    guint32 datacsum = compute_checksum(cd->in, cd->ncbytes, 0);
+    guint8 sizecsum[4];
+    guint16 nbytes_le;
+
+    nbytes_le = GUINT16_TO_LE (cd->ncbytes);
+    memcpy (&sizecsum[0], &nbytes_le, 2);
+    nbytes_le = GUINT16_TO_LE (cd->nubytes);
+    memcpy (&sizecsum[2], &nbytes_le, 2);
+    cd->checksum = compute_checksum (sizecsum, sizeof(sizecsum), datacsum);
     GOutputStream *stream = g_filter_output_stream_get_base_stream (G_FILTER_OUTPUT_STREAM (out));
 
     *bytes_written = 0;
@@ -452,32 +483,58 @@ cdata_finish (cdata_t *cd, GError **error)
 }
 
 G_GNUC_INTERNAL gboolean
-cdata_read (cdata_t *cd, u1 res_data, gint comptype,
+cdata_read (cdata_t *cd, guint8 res_data, gint comptype,
             GDataInputStream *in, GCancellable *cancellable, GError **error)
 
 {
     gboolean success = FALSE;
     int ret, zret = Z_OK;
     gint compression = comptype & GCAB_COMPRESSION_MASK;
-    guint8 *buf = compression == GCAB_COMPRESSION_NONE ? cd->out : cd->in;
-    CHECKSUM datacsum;
+    gsize buf_sz;
+    guint8 *buf = NULL;
+    guint32 datacsum;
+    guint8 sizecsum[4];
+    guint16 nbytes_le;
 
-    if (compression > GCAB_COMPRESSION_MSZIP &&
-        compression != GCAB_COMPRESSION_LZX) {
+    /* decompress directly into ->out for no decompression */
+    switch (compression) {
+    case GCAB_COMPRESSION_NONE:
+        buf = cd->out;
+        buf_sz = sizeof(cd->out);
+        break;
+    case GCAB_COMPRESSION_MSZIP:
+    case GCAB_COMPRESSION_LZX:
+        buf = cd->in;
+        buf_sz = sizeof(cd->in);
+        break;
+    default:
         g_set_error (error, GCAB_ERROR, GCAB_ERROR_FAILED,
                      _("unsupported compression method %d"), compression);
-        return FALSE;
+        break;
     }
+    if (buf == NULL)
+        return FALSE;
 
     R4 (cd->checksum);
     R2 (cd->ncbytes);
+    if (cd->ncbytes > buf_sz) {
+        g_set_error (error, GCAB_ERROR, GCAB_ERROR_FAILED,
+                     "tried to decompress %" G_GUINT16_FORMAT " bytes "
+                     "into buffer of size %" G_GSIZE_FORMAT,
+                     cd->ncbytes, buf_sz);
+        return FALSE;
+    }
     R2 (cd->nubytes);
     cd->reserved = g_malloc (res_data);
     RN (cd->reserved, res_data);
     RN (buf, cd->ncbytes);
 
     datacsum = compute_checksum(buf, cd->ncbytes, 0);
-    if (cd->checksum != compute_checksum ((guint8*)&cd->ncbytes, 4, datacsum)) {
+    nbytes_le = GUINT16_TO_LE (cd->ncbytes);
+    memcpy (&sizecsum[0], &nbytes_le, 2);
+    nbytes_le = GUINT16_TO_LE (cd->nubytes);
+    memcpy (&sizecsum[2], &nbytes_le, 2);
+    if (cd->checksum != compute_checksum (sizecsum, sizeof(sizecsum), datacsum)) {
         g_set_error_literal (error, GCAB_ERROR, GCAB_ERROR_FAILED,
                              _("incorrect checksum detected"));
         return FALSE;
@@ -562,7 +619,7 @@ end:
         g_set_error (error, GCAB_ERROR, GCAB_ERROR_FAILED,
                      "zlib failed: %s", zError (zret));
 
-    if (!*error && !success)
+    if (error != NULL && *error == NULL && !success)
         g_set_error (error, GCAB_ERROR, GCAB_ERROR_FAILED,
                      "Invalid cabinet chunk");
 
