@@ -20,6 +20,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
+#include "config.h"
+
 #include <string.h>
 #include "decomp.h"
 
@@ -190,7 +192,9 @@ struct Ziphuft **t, cab_LONG *m, fdi_decomp_state *decomp_state)
           xp = ZIP(c) + k;
           while (++j < z)       /* try smaller tables up to z bits */
           {
-            if ((f <<= 1) <= *++xp)
+            if (*++xp > ZIPBMAX)
+              return 2;         /* corrupt */
+            if ((f <<= 1) <= *xp)
               break;            /* enough codes to use up j bits */
             f -= *xp;           /* else deduct codes from patterns */
           }
@@ -248,6 +252,10 @@ struct Ziphuft **t, cab_LONG *m, fdi_decomp_state *decomp_state)
         i ^= j;
       i ^= j;
 
+      /* no tables */
+      if (h < 0)
+        return 2;               /* corrupt */
+
       /* backup over finished tables */
       while ((i & ((1 << w) - 1)) != ZIP(x)[h])
         w -= l[--h];            /* don't need to update q */
@@ -881,6 +889,7 @@ int LZXfdi_decomp(int inlen, int outlen, fdi_decomp_state *decomp_state) {
         for (i = 0; i < 8; i++) { READ_BITS(j, 3); LENTABLE(ALIGNED)[i] = j; }
         BUILD_TABLE(ALIGNED);
         /* rest of aligned header is same as verbatim */
+        /* fall-thru */
 
       case LZX_BLOCKTYPE_VERBATIM:
         READ_LENGTHS(MAINTREE, 0, 256, fdi_lzx_read_lens);
