@@ -1,3 +1,25 @@
+/*
+ * LibGCab
+ * Copyright (c) 2012, Marc-André Lureau <marcandre.lureau@gmail.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
+ */
+
+#include "config.h"
+
 #include <glib/gi18n-lib.h>
 #include "gcab-priv.h"
 
@@ -76,12 +98,12 @@ gcab_cabinet_set_property (GObject *object, guint prop_id, const GValue *value,
         if (self->reserved)
             g_byte_array_unref (self->reserved);
         self->reserved = g_value_dup_boxed (value);
-	break;
+        break;
     case PROP_SIGNATURE:
         if (self->signature)
             g_byte_array_unref (self->signature);
         self->signature = g_value_dup_boxed (value);
-	break;
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -97,7 +119,7 @@ gcab_cabinet_get_property (GObject *object, guint prop_id, GValue *value, GParam
     switch (prop_id) {
     case PROP_RESERVED:
         g_value_set_boxed (value, self->reserved);
-	break;
+        break;
     case PROP_SIGNATURE:
         g_value_set_boxed (value, gcab_cabinet_get_signature (self, NULL, NULL));
         break;
@@ -149,6 +171,15 @@ gcab_cabinet_add_folder (GCabCabinet *self,
     g_return_val_if_fail (GCAB_IS_FOLDER (folder), FALSE);
     g_return_val_if_fail (!error || *error == NULL, FALSE);
 
+    for (guint i = 0; i < self->folders->len; i++) {
+        GCabFolder *folder_tmp = g_ptr_array_index (self->folders, i);
+        if (folder_tmp == folder) {
+            g_set_error (error, GCAB_ERROR, GCAB_ERROR_FORMAT,
+                         "Folder has already been added");
+            return FALSE;
+        }
+    }
+
     g_ptr_array_add (self->folders, g_object_ref (folder));
 
     return TRUE;
@@ -162,7 +193,7 @@ gcab_cabinet_add_folder (GCabCabinet *self,
  * Note that Cabinet folders are not like filesystem path, they are
  * group of files sharing some layout parameters.
  *
- * Returns: (element-type GCabFolder) (transfer full): an array of #GCabFolder
+ * Returns: (element-type GCabFolder) (transfer none): an array of #GCabFolder
  **/
 GPtrArray *
 gcab_cabinet_get_folders (GCabCabinet *self)
@@ -223,7 +254,6 @@ gcab_cabinet_write (GCabCabinet *self,
     size_t sumstr = 0;
     GSList *l, *files;
     cfile_t *prevf = NULL;
-    int i;
 
     dstream = g_data_output_stream_new (out);
     g_data_output_stream_set_byte_order (dstream, G_DATA_STREAM_BYTE_ORDER_LITTLE_ENDIAN);
@@ -246,7 +276,7 @@ gcab_cabinet_write (GCabCabinet *self,
     folder.ndatab = gcab_folder_get_ndatablocks (cabfolder);
 
     /* avoid seeking to allow growing output streams */
-    for (i = 0; i < folder.offsetdata; i++)
+    for (guint i = 0; i < folder.offsetdata; i++)
         if (!g_data_output_stream_put_byte (dstream, 0, cancellable, error))
             goto end;
 
@@ -257,7 +287,7 @@ gcab_cabinet_write (GCabCabinet *self,
 
         g_clear_object (&in);
         in = G_INPUT_STREAM (g_file_read (file->file, cancellable, error));
-        if (*error)
+        if (in == NULL)
             goto end;
 
         while ((len = g_input_stream_read (in,
@@ -385,7 +415,6 @@ gcab_cabinet_load (GCabCabinet *self,
 
     gboolean success = FALSE;
     cheader_t cheader;
-    int i;
     GDataInputStream *in = g_data_input_stream_new (stream);
     g_filter_input_stream_set_close_base_stream (G_FILTER_INPUT_STREAM (in), FALSE);
     g_data_input_stream_set_byte_order (in, G_DATA_STREAM_BYTE_ORDER_LITTLE_ENDIAN);
@@ -400,7 +429,7 @@ gcab_cabinet_load (GCabCabinet *self,
                       g_byte_array_new_take (cheader.reserved, cheader.res_header),
                       NULL);
 
-    for (i = 0; i < cheader.nfolders; i++) {
+    for (guint i = 0; i < cheader.nfolders; i++) {
         cfolder_t cfolder = { 0, };
         if (!cfolder_read (&cfolder, cheader.res_folder, in, cancellable, error))
             goto end;
@@ -414,7 +443,7 @@ gcab_cabinet_load (GCabCabinet *self,
         cfolder.reserved = NULL;
     }
 
-    for (i = 0; i < cheader.nfiles; i++) {
+    for (guint i = 0; i < cheader.nfiles; i++) {
         cfile_t cfile = { 0, };
         if (!cfile_read (&cfile, in, cancellable, error))
             goto end;
@@ -451,7 +480,7 @@ end:
  * gcab_cabinet_extract:
  * @cabinet: a #GCabCabinet
  * @path: the path to extract files
- * @file_callback: (allow-none) (scope call) (closure user_data): an optionnal #GCabFile callback,
+ * @file_callback: (allow-none) (scope call) (closure user_data): an optional #GCabFile callback,
  *     return %FALSE to filter out or skip files.
  * @progress_callback: (allow-none) (scope call) (closure user_data): a progress callback
  * @user_data: (closure): callback data
@@ -473,14 +502,13 @@ gcab_cabinet_extract (GCabCabinet *self,
                       GError **error)
 {
     gboolean success = TRUE;
-    int i;
 
     g_return_val_if_fail (GCAB_IS_CABINET (self), FALSE);
     g_return_val_if_fail (G_IS_FILE (path), FALSE);
     g_return_val_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable), FALSE);
     g_return_val_if_fail (!error || *error == NULL, FALSE);
 
-    for (i = 0; i < self->folders->len; ++i) {
+    for (guint i = 0; i < self->folders->len; ++i) {
         GCabFolder *folder = g_ptr_array_index (self->folders, i);
         if (!gcab_folder_extract (folder, path, self->cheader.res_data,
                                   file_callback, progress_callback, user_data,
@@ -497,7 +525,7 @@ gcab_cabinet_extract (GCabCabinet *self,
  * gcab_cabinet_extract_simple:
  * @cabinet: a #GCabCabinet
  * @path: the path to extract files
- * @file_callback: (allow-none) (scope call) (closure user_data): an optionnal #GCabFile callback,
+ * @file_callback: (allow-none) (scope call) (closure user_data): an optional #GCabFile callback,
  *     return %FALSE to filter out or skip files.
  * @user_data: (closure): callback data
  * @cancellable: (allow-none): optional #GCancellable object,
