@@ -1,3 +1,25 @@
+/*
+ * LibGCab
+ * Copyright (c) 2012, Marc-André Lureau <marcandre.lureau@gmail.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
+ */
+
+#include "config.h"
+
 #include "gcab-priv.h"
 #include "gcab-file.h"
 
@@ -136,7 +158,7 @@ gcab_file_update_info (GCabFile *self, GFileInfo *info)
 
     g_file_info_get_modification_time (info, &tv);
     time = tv.tv_sec;
-    m = localtime (&time);
+    m = gmtime (&time);
 
     self->cfile.name = self->name;
     self->cfile.usize = g_file_info_get_size (info);
@@ -149,7 +171,7 @@ gcab_file_update_info (GCabFile *self, GFileInfo *info)
 }
 
 G_GNUC_INTERNAL gboolean
-gcab_file_set_uoffset (GCabFile *self, u4 uoffset)
+gcab_file_set_uoffset (GCabFile *self, guint32 uoffset)
 {
     g_return_val_if_fail (GCAB_IS_FILE (self), FALSE);
 
@@ -180,9 +202,8 @@ gcab_file_get_size (GCabFile *self)
  * @file: a #GCabFile
  * @result: a #GTimeVal to return date
  *
- * Get the file date.
+ * Get the file date, in @result.
  *
- * Returns: the cabinet file date in @result
  * Since: 0.6
  **/
 void
@@ -254,7 +275,7 @@ gcab_file_get_name (GCabFile *self)
  * If @file is from an existing cabinet, the fuction will return
  * %NULL.
  *
- * Returns: (transfer full): the associated #GFile or %NULL
+ * Returns: (transfer none): the associated #GFile or %NULL
  **/
 GFile *
 gcab_file_get_file (GCabFile *self)
