@@ -17,6 +17,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA 02110-1301 USA
  */
+
 #ifndef _GCAB_FILE_H_
 #define _GCAB_FILE_H_
 
@@ -34,6 +35,27 @@ G_BEGIN_DECLS
 
 typedef struct _GCabFileClass GCabFileClass;
 
+/**
+ * GCabFileAttribute:
+ * @GCAB_FILE_ATTRIBUTE_RDONLY: file is read-only
+ * @GCAB_FILE_ATTRIBUTE_HIDDEN: file is hidden
+ * @GCAB_FILE_ATTRIBUTE_SYSTEM: file is a system file
+ * @GCAB_FILE_ATTRIBUTE_ARCH: file modified since last backup
+ * @GCAB_FILE_ATTRIBUTE_EXEC: run after extraction
+ * @GCAB_FILE_ATTRIBUTE_NAME_IS_UTF: name contains UTF
+ *
+ * Attributes associated with the #GCabFile.
+ **/
+typedef enum
+{
+  GCAB_FILE_ATTRIBUTE_RDONLY      = 0x01,
+  GCAB_FILE_ATTRIBUTE_HIDDEN      = 0x02,
+  GCAB_FILE_ATTRIBUTE_SYSTEM      = 0x04,
+  GCAB_FILE_ATTRIBUTE_ARCH        = 0x20,
+  GCAB_FILE_ATTRIBUTE_EXEC        = 0x40,
+  GCAB_FILE_ATTRIBUTE_NAME_IS_UTF = 0x80
+} GCabFileAttribute;
+
 /**
  * GCabFile:
  *
@@ -56,6 +78,9 @@ GType gcab_file_get_type (void) G_GNUC_CONST;
 GCabFile *      gcab_file_new_with_file             (const gchar *name, GFile *file);
 GFile *         gcab_file_get_file                  (GCabFile *file);
 const gchar *   gcab_file_get_name                  (GCabFile *file);
+guint32         gcab_file_get_size                  (GCabFile *file);
+guint32         gcab_file_get_attributes            (GCabFile *file);
+void            gcab_file_get_date                  (GCabFile *file, GTimeVal *result);
 const gchar *   gcab_file_get_extract_name          (GCabFile *file);
 void            gcab_file_set_extract_name          (GCabFile *file, const gchar *name);
 
