@@ -1,3 +1,27 @@
+/*
+ * LibGCab
+ * Copyright (c) 2012, Marc-André Lureau <marcandre.lureau@gmail.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
+ */
+
+#include "config.h"
+
+#include <strings.h>
+
 #include "gcab-priv.h"
 
 /**
@@ -71,7 +95,7 @@ gcab_folder_set_property (GObject *object, guint prop_id, const GValue *value, G
         if (self->reserved)
             g_byte_array_unref (self->reserved);
         self->reserved = g_value_dup_boxed (value);
-	break;
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -93,7 +117,7 @@ gcab_folder_get_property (GObject *object, guint prop_id, GValue *value, GParamS
         break;
     case PROP_RESERVED:
         g_value_set_boxed (value, self->reserved);
-	break;
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -204,7 +228,7 @@ add_file_info (GCabFolder *self, GCabFile *file, GFileInfo *info,
 
     } else {
         g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                     "Unhandled file type: %d", file_type);
+                     "Unhandled file type: %u", file_type);
         return FALSE;
     }
 
@@ -240,7 +264,7 @@ gcab_folder_add_file (GCabFolder *self, GCabFile *file,
         g_return_val_if_fail (G_IS_FILE (gfile), FALSE);
 
         GFileInfo *info = g_file_query_info (gfile, FILE_ATTRS, 0, NULL, error);
-        if (*error)
+        if (info == NULL)
             return FALSE;
 
         success = add_file_info (self, file, info,
@@ -306,7 +330,7 @@ gcab_folder_new_with_cfolder (const cfolder_t *folder, GInputStream *stream)
  *
  * Get the list of #GCabFile files contained in the @cabfolder.
  *
- * Returns: (element-type GCabFile) (transfer full): list of files
+ * Returns: (element-type GCabFile) (transfer container): list of files
  **/
 GSList *
 gcab_folder_get_files (GCabFolder *self)
@@ -328,7 +352,7 @@ sort_by_offset (GCabFile *a, GCabFile *b)
 G_GNUC_INTERNAL gboolean
 gcab_folder_extract (GCabFolder *self,
                      GFile *path,
-                     u1 res_data,
+                     guint8 res_data,
                      GCabFileCallback file_callback,
                      GFileProgressCallback progress_callback,
                      gpointer callback_data,
@@ -341,7 +365,7 @@ gcab_folder_extract (GCabFolder *self,
     GFileOutputStream *out = NULL;
     GSList *f, *files = NULL;
     cdata_t cdata = { 0, };
-    u4 nubytes = 0;
+    guint32 nubytes = 0;
 
     data = g_data_input_stream_new (self->stream);
     g_data_input_stream_set_byte_order (data, G_DATA_STREAM_BYTE_ORDER_LITTLE_ENDIAN);
@@ -402,8 +426,8 @@ gcab_folder_extract (GCabFolder *self,
         if (!out)
             goto end;
 
-        u4 usize = file->cfile.usize;
-        u4 uoffset = file->cfile.uoffset;
+        guint32 usize = file->cfile.usize;
+        guint32 uoffset = file->cfile.uoffset;
 
         /* let's rewind if need be */
         if (uoffset < nubytes) {
@@ -438,8 +462,7 @@ gcab_folder_extract (GCabFolder *self,
     success = TRUE;
 
 end:
-    if (files)
-        g_slist_free (files);
+    g_slist_free (files);
 
     g_clear_object (&data);
     g_clear_object (&out);
